@@ -1,8 +1,7 @@
-import requests
-import json
 import logging
+
 from .api_client import APIClient
-from ..exceptions.UnauthorizedException import UnauthorizedException
+
 
 # child class of APIClient --> Extends error handling functionality
 # PresenceClient class contains a series of functions corresponding to all
